Class: MuxRuby::CreateAssetRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/mux_ruby/models/create_asset_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateAssetRequest

Initializes the object



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/mux_ruby/models/create_asset_request.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MuxRuby::CreateAssetRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MuxRuby::CreateAssetRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'input')
    if (value = attributes[:'input']).is_a?(Array)
      self.input = value
    end
  end

  if attributes.key?(:'inputs')
    if (value = attributes[:'inputs']).is_a?(Array)
      self.inputs = value
    end
  end

  if attributes.key?(:'playback_policy')
    if (value = attributes[:'playback_policy']).is_a?(Array)
      self.playback_policy = value
    end
  end

  if attributes.key?(:'playback_policies')
    if (value = attributes[:'playback_policies']).is_a?(Array)
      self.playback_policies = value
    end
  end

  if attributes.key?(:'advanced_playback_policies')
    if (value = attributes[:'advanced_playback_policies']).is_a?(Array)
      self.advanced_playback_policies = value
    end
  end

  if attributes.key?(:'per_title_encode')
    self.per_title_encode = attributes[:'per_title_encode']
  end

  if attributes.key?(:'passthrough')
    self.passthrough = attributes[:'passthrough']
  end

  if attributes.key?(:'mp4_support')
    self.mp4_support = attributes[:'mp4_support']
  end

  if attributes.key?(:'normalize_audio')
    self.normalize_audio = attributes[:'normalize_audio']
  else
    self.normalize_audio = false
  end

  if attributes.key?(:'master_access')
    self.master_access = attributes[:'master_access']
  end

  if attributes.key?(:'test')
    self.test = attributes[:'test']
  end

  if attributes.key?(:'max_resolution_tier')
    self.max_resolution_tier = attributes[:'max_resolution_tier']
  end

  if attributes.key?(:'encoding_tier')
    self.encoding_tier = attributes[:'encoding_tier']
  end

  if attributes.key?(:'video_quality')
    self.video_quality = attributes[:'video_quality']
  end

  if attributes.key?(:'static_renditions')
    if (value = attributes[:'static_renditions']).is_a?(Array)
      self.static_renditions = value
    end
  end

  if attributes.key?(:'meta')
    self.meta = attributes[:'meta']
  end
end

Instance Attribute Details

#advanced_playback_policiesObject

An array of playback policy objects that you want applied to this asset and available through playback_ids. advanced_playback_policies must be used instead of playback_policies when creating a DRM playback ID.



31
32
33
# File 'lib/mux_ruby/models/create_asset_request.rb', line 31

def advanced_playback_policies
  @advanced_playback_policies
end

#encoding_tierObject

This field is deprecated. Please use video_quality instead. The encoding tier informs the cost, quality, and available platform features for the asset. The default encoding tier for an account can be set in the Mux Dashboard. [See the video quality guide for more details.](docs.mux.com/guides/use-video-quality-levels)



54
55
56
# File 'lib/mux_ruby/models/create_asset_request.rb', line 54

def encoding_tier
  @encoding_tier
end

#inputObject

Deprecated. Use inputs instead, which accepts an identical type.



19
20
21
# File 'lib/mux_ruby/models/create_asset_request.rb', line 19

def input
  @input
end

#inputsObject

An array of objects that each describe an input file to be used to create the asset. As a shortcut, input can also be a string URL for a file when only one input file is used. See input[].url for requirements.



22
23
24
# File 'lib/mux_ruby/models/create_asset_request.rb', line 22

def inputs
  @inputs
end

#master_accessObject

Specify what level (if any) of support for master access. Master access can be enabled temporarily for your asset to be downloaded. See the [Download your videos guide](docs.mux.com/guides/enable-static-mp4-renditions) for more information.



45
46
47
# File 'lib/mux_ruby/models/create_asset_request.rb', line 45

def master_access
  @master_access
end

#max_resolution_tierObject

Max resolution tier can be used to control the maximum resolution_tier your asset is encoded, stored, and streamed at. If not set, this defaults to 1080p.



51
52
53
# File 'lib/mux_ruby/models/create_asset_request.rb', line 51

def max_resolution_tier
  @max_resolution_tier
end

#metaObject

Returns the value of attribute meta.



62
63
64
# File 'lib/mux_ruby/models/create_asset_request.rb', line 62

def meta
  @meta
end

#mp4_supportObject

Deprecated. See the [Static Renditions API](www.mux.com/docs/guides/enable-static-mp4-renditions) for the updated API. Specify what level of support for mp4 playback. You may not enable both mp4_support and static_renditions. * The capped-1080p option produces a single MP4 file, called capped-1080p.mp4, with the video resolution capped at 1080p. This option produces an audio.m4a file for an audio-only asset. * The audio-only option produces a single M4A file, called audio.m4a for a video or an audio-only asset. MP4 generation will error when this option is specified for a video-only asset. * The ‘audio-only,capped-1080p` option produces both the audio.m4a and capped-1080p.mp4 files. Only the capped-1080p.mp4 file is produced for a video-only asset, while only the audio.m4a file is produced for an audio-only asset. The standard(deprecated) option produces up to three MP4 files with different levels of resolution (high.mp4, medium.mp4, low.mp4, or audio.m4a for an audio-only asset). MP4 files are not produced for none (default). In most cases you should use our default HLS-based streaming playback (`playback_id.m3u8`) which can automatically adjust to viewers’ connection speeds, but an mp4 can be useful for some legacy devices or downloading for offline playback. See the [Download your videos guide](docs.mux.com/guides/enable-static-mp4-renditions) for more information.



39
40
41
# File 'lib/mux_ruby/models/create_asset_request.rb', line 39

def mp4_support
  @mp4_support
end

#normalize_audioObject

Normalize the audio track loudness level. This parameter is only applicable to on-demand (not live) assets.



42
43
44
# File 'lib/mux_ruby/models/create_asset_request.rb', line 42

def normalize_audio
  @normalize_audio
end

#passthroughObject

You can set this field to anything you want. It will be included in the asset details and related webhooks. If you’re looking for more structured metadata, such as title or external_id, you can use the meta object instead. **Max: 255 characters**.



36
37
38
# File 'lib/mux_ruby/models/create_asset_request.rb', line 36

def passthrough
  @passthrough
end

#per_title_encodeObject

Returns the value of attribute per_title_encode.



33
34
35
# File 'lib/mux_ruby/models/create_asset_request.rb', line 33

def per_title_encode
  @per_title_encode
end

#playback_policiesObject

An array of playback policy names that you want applied to this asset and available through playback_ids. Options include: * ‘\“public\”` (anyone with the playback URL can stream the asset). * `\“signed\”` (an additional access token is required to play the asset). If no playback_policies are set, the asset will have no playback IDs and will therefore not be playable. For simplicity, a single string name can be used in place of the array in the case of only one playback policy.



28
29
30
# File 'lib/mux_ruby/models/create_asset_request.rb', line 28

def playback_policies
  @playback_policies
end

#playback_policyObject

Deprecated. Use playback_policies instead, which accepts an identical type.



25
26
27
# File 'lib/mux_ruby/models/create_asset_request.rb', line 25

def playback_policy
  @playback_policy
end

#static_renditionsObject

An array of static renditions to create for this asset. You may not enable both static_renditions and ‘mp4_support (the latter being deprecated)`



60
61
62
# File 'lib/mux_ruby/models/create_asset_request.rb', line 60

def static_renditions
  @static_renditions
end

#testObject

Marks the asset as a test asset when the value is set to true. A Test asset can help evaluate the Mux Video APIs without incurring any cost. There is no limit on number of test assets created. Test asset are watermarked with the Mux logo, limited to 10 seconds, deleted after 24 hrs.



48
49
50
# File 'lib/mux_ruby/models/create_asset_request.rb', line 48

def test
  @test
end

#video_qualityObject

The video quality controls the cost, quality, and available platform features for the asset. The default video quality for an account can be set in the Mux Dashboard. This field replaces the deprecated encoding_tier value. [See the video quality guide for more details.](docs.mux.com/guides/use-video-quality-levels)



57
58
59
# File 'lib/mux_ruby/models/create_asset_request.rb', line 57

def video_quality
  @video_quality
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/mux_ruby/models/create_asset_request.rb', line 109

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/mux_ruby/models/create_asset_request.rb', line 87

def self.attribute_map
  {
    :'input' => :'input',
    :'inputs' => :'inputs',
    :'playback_policy' => :'playback_policy',
    :'playback_policies' => :'playback_policies',
    :'advanced_playback_policies' => :'advanced_playback_policies',
    :'per_title_encode' => :'per_title_encode',
    :'passthrough' => :'passthrough',
    :'mp4_support' => :'mp4_support',
    :'normalize_audio' => :'normalize_audio',
    :'master_access' => :'master_access',
    :'test' => :'test',
    :'max_resolution_tier' => :'max_resolution_tier',
    :'encoding_tier' => :'encoding_tier',
    :'video_quality' => :'video_quality',
    :'static_renditions' => :'static_renditions',
    :'meta' => :'meta'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



346
347
348
# File 'lib/mux_ruby/models/create_asset_request.rb', line 346

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



136
137
138
139
# File 'lib/mux_ruby/models/create_asset_request.rb', line 136

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/mux_ruby/models/create_asset_request.rb', line 114

def self.openapi_types
  {
    :'input' => :'Array<InputSettings>',
    :'inputs' => :'Array<InputSettings>',
    :'playback_policy' => :'Array<PlaybackPolicy>',
    :'playback_policies' => :'Array<PlaybackPolicy>',
    :'advanced_playback_policies' => :'Array<CreatePlaybackIDRequest>',
    :'per_title_encode' => :'Boolean',
    :'passthrough' => :'String',
    :'mp4_support' => :'String',
    :'normalize_audio' => :'Boolean',
    :'master_access' => :'String',
    :'test' => :'Boolean',
    :'max_resolution_tier' => :'String',
    :'encoding_tier' => :'String',
    :'video_quality' => :'String',
    :'static_renditions' => :'Array<CreateStaticRenditionRequest>',
    :'meta' => :'AssetMetadata'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/mux_ruby/models/create_asset_request.rb', line 310

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      input == o.input &&
      inputs == o.inputs &&
      playback_policy == o.playback_policy &&
      playback_policies == o.playback_policies &&
      advanced_playback_policies == o.advanced_playback_policies &&
      per_title_encode == o.per_title_encode &&
      passthrough == o.passthrough &&
      mp4_support == o.mp4_support &&
      normalize_audio == o.normalize_audio &&
      master_access == o.master_access &&
      test == o.test &&
      max_resolution_tier == o.max_resolution_tier &&
      encoding_tier == o.encoding_tier &&
      video_quality == o.video_quality &&
      static_renditions == o.static_renditions &&
      meta == o.meta
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/mux_ruby/models/create_asset_request.rb', line 376

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = MuxRuby.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/mux_ruby/models/create_asset_request.rb', line 447

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/mux_ruby/models/create_asset_request.rb', line 353

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


333
334
335
# File 'lib/mux_ruby/models/create_asset_request.rb', line 333

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



339
340
341
# File 'lib/mux_ruby/models/create_asset_request.rb', line 339

def hash
  [input, inputs, playback_policy, playback_policies, advanced_playback_policies, per_title_encode, passthrough, mp4_support, normalize_audio, master_access, test, max_resolution_tier, encoding_tier, video_quality, static_renditions, meta].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



237
238
239
240
# File 'lib/mux_ruby/models/create_asset_request.rb', line 237

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



423
424
425
# File 'lib/mux_ruby/models/create_asset_request.rb', line 423

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/mux_ruby/models/create_asset_request.rb', line 429

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



417
418
419
# File 'lib/mux_ruby/models/create_asset_request.rb', line 417

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/mux_ruby/models/create_asset_request.rb', line 244

def valid?
  mp4_support_validator = EnumAttributeValidator.new('String', ["none", "standard", "capped-1080p", "audio-only", "audio-only,capped-1080p"])
  return false unless mp4_support_validator.valid?(@mp4_support)
  master_access_validator = EnumAttributeValidator.new('String', ["none", "temporary"])
  return false unless master_access_validator.valid?(@master_access)
  max_resolution_tier_validator = EnumAttributeValidator.new('String', ["1080p", "1440p", "2160p"])
  return false unless max_resolution_tier_validator.valid?(@max_resolution_tier)
  encoding_tier_validator = EnumAttributeValidator.new('String', ["smart", "baseline", "premium"])
  return false unless encoding_tier_validator.valid?(@encoding_tier)
  video_quality_validator = EnumAttributeValidator.new('String', ["basic", "plus", "premium"])
  return false unless video_quality_validator.valid?(@video_quality)
  true
end