Class: MuxRuby::CreateLiveStreamRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/mux_ruby/models/create_live_stream_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateLiveStreamRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MuxRuby::CreateLiveStreamRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MuxRuby::CreateLiveStreamRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'playback_policy')
    if (value = attributes[:'playback_policy']).is_a?(Array)
      self.playback_policy = value
    end
  end

  if attributes.key?(:'playback_policies')
    if (value = attributes[:'playback_policies']).is_a?(Array)
      self.playback_policies = value
    end
  end

  if attributes.key?(:'advanced_playback_policies')
    if (value = attributes[:'advanced_playback_policies']).is_a?(Array)
      self.advanced_playback_policies = value
    end
  end

  if attributes.key?(:'new_asset_settings')
    self.new_asset_settings = attributes[:'new_asset_settings']
  end

  if attributes.key?(:'reconnect_window')
    self.reconnect_window = attributes[:'reconnect_window']
  else
    self.reconnect_window = 60
  end

  if attributes.key?(:'use_slate_for_standard_latency')
    self.use_slate_for_standard_latency = attributes[:'use_slate_for_standard_latency']
  else
    self.use_slate_for_standard_latency = false
  end

  if attributes.key?(:'reconnect_slate_url')
    self.reconnect_slate_url = attributes[:'reconnect_slate_url']
  end

  if attributes.key?(:'passthrough')
    self.passthrough = attributes[:'passthrough']
  end

  if attributes.key?(:'audio_only')
    self.audio_only = attributes[:'audio_only']
  end

  if attributes.key?(:'embedded_subtitles')
    if (value = attributes[:'embedded_subtitles']).is_a?(Array)
      self.embedded_subtitles = value
    end
  end

  if attributes.key?(:'generated_subtitles')
    if (value = attributes[:'generated_subtitles']).is_a?(Array)
      self.generated_subtitles = value
    end
  end

  if attributes.key?(:'reduced_latency')
    self.reduced_latency = attributes[:'reduced_latency']
  end

  if attributes.key?(:'low_latency')
    self.low_latency = attributes[:'low_latency']
  end

  if attributes.key?(:'latency_mode')
    self.latency_mode = attributes[:'latency_mode']
  end

  if attributes.key?(:'test')
    self.test = attributes[:'test']
  end

  if attributes.key?(:'simulcast_targets')
    if (value = attributes[:'simulcast_targets']).is_a?(Array)
      self.simulcast_targets = value
    end
  end

  if attributes.key?(:'max_continuous_duration')
    self.max_continuous_duration = attributes[:'max_continuous_duration']
  else
    self.max_continuous_duration = 43200
  end
end

Instance Attribute Details

#advanced_playback_policiesObject

An array of playback policy objects that you want applied on this live stream and available through playback_ids. advanced_playback_policies must be used instead of playback_policies when creating a DRM playback ID.



25
26
27
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 25

def advanced_playback_policies
  @advanced_playback_policies
end

#audio_onlyObject

Force the live stream to only process the audio track when the value is set to true. Mux drops the video track if broadcasted.



41
42
43
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 41

def audio_only
  @audio_only
end

#embedded_subtitlesObject

Describe the embedded closed caption contents of the incoming live stream.



44
45
46
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 44

def embedded_subtitles
  @embedded_subtitles
end

#generated_subtitlesObject

Configure the incoming live stream to include subtitles created with automatic speech recognition. Each Asset created from a live stream with generated_subtitles configured will automatically receive two text tracks. The first of these will have a text_source value of generated_live, and will be available with ready status as soon as the stream is live. The second text track will have a text_source value of generated_live_final and will contain subtitles with improved accuracy, timing, and formatting. However, generated_live_final tracks will not be available in ready status until the live stream ends. If an Asset has both generated_live and generated_live_final tracks that are ready, then only the generated_live_final track will be included during playback.



47
48
49
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 47

def generated_subtitles
  @generated_subtitles
end

#latency_modeObject

Latency is the time from when the streamer transmits a frame of video to when you see it in the player. Set this as an alternative to setting low latency or reduced latency flags.



56
57
58
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 56

def latency_mode
  @latency_mode
end

#low_latencyObject

This field is deprecated. Please use latency_mode instead. Latency is the time from when the streamer transmits a frame of video to when you see it in the player. Setting this option will enable compatibility with the LL-HLS specification for low-latency streaming. This typically has lower latency than Reduced Latency streams, and cannot be combined with Reduced Latency.



53
54
55
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 53

def low_latency
  @low_latency
end

#max_continuous_durationObject

The time in seconds a live stream may be continuously active before being disconnected. Defaults to 12 hours.



64
65
66
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 64

def max_continuous_duration
  @max_continuous_duration
end

#new_asset_settingsObject

Returns the value of attribute new_asset_settings.



27
28
29
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 27

def new_asset_settings
  @new_asset_settings
end

#passthroughObject

Returns the value of attribute passthrough.



38
39
40
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 38

def passthrough
  @passthrough
end

#playback_policiesObject

An array of playback policy names that you want applied to this live stream and available through playback_ids. Options include: * ‘\“public\”` (anyone with the playback URL can stream the live stream). * `\“signed\”` (an additional access token is required to play the live stream). If no playback_policies is set, the live stream will have no playback IDs and will therefore not be playable. For simplicity, a single string name can be used in place of the array in the case of only one playback policy.



22
23
24
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 22

def playback_policies
  @playback_policies
end

#playback_policyObject

Deprecated. Use playback_policies instead, which accepts an identical type.



19
20
21
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 19

def playback_policy
  @playback_policy
end

#reconnect_slate_urlObject

The URL of the image file that Mux should download and use as slate media during interruptions of the live stream media. This file will be downloaded each time a new recorded asset is created from the live stream. If this is not set, the default slate media will be used.



36
37
38
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 36

def reconnect_slate_url
  @reconnect_slate_url
end

#reconnect_windowObject

When live streaming software disconnects from Mux, either intentionally or due to a drop in the network, the Reconnect Window is the time in seconds that Mux should wait for the streaming software to reconnect before considering the live stream finished and completing the recorded asset. Defaults to 60 seconds on the API if not specified. If not specified directly, Standard Latency streams have a Reconnect Window of 60 seconds; Reduced and Low Latency streams have a default of 0 seconds, or no Reconnect Window. For that reason, we suggest specifying a value other than zero for Reduced and Low Latency streams. Reduced and Low Latency streams with a Reconnect Window greater than zero will insert slate media into the recorded asset while waiting for the streaming software to reconnect or when there are brief interruptions in the live stream media. When using a Reconnect Window setting higher than 60 seconds with a Standard Latency stream, we highly recommend enabling slate with the use_slate_for_standard_latency option.



30
31
32
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 30

def reconnect_window
  @reconnect_window
end

#reduced_latencyObject

This field is deprecated. Please use latency_mode instead. Latency is the time from when the streamer transmits a frame of video to when you see it in the player. Set this if you want lower latency for your live stream. Read more here: mux.com/blog/reduced-latency-for-mux-live-streaming-now-available/



50
51
52
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 50

def reduced_latency
  @reduced_latency
end

#simulcast_targetsObject

Returns the value of attribute simulcast_targets.



61
62
63
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 61

def simulcast_targets
  @simulcast_targets
end

#testObject

Marks the live stream as a test live stream when the value is set to true. A test live stream can help evaluate the Mux Video APIs without incurring any cost. There is no limit on number of test live streams created. Test live streams are watermarked with the Mux logo and limited to 5 minutes. The test live stream is disabled after the stream is active for 5 mins and the recorded asset also deleted after 24 hours.



59
60
61
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 59

def test
  @test
end

#use_slate_for_standard_latencyObject

By default, Standard Latency live streams do not have slate media inserted while waiting for live streaming software to reconnect to Mux. Setting this to true enables slate insertion on a Standard Latency stream.



33
34
35
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 33

def use_slate_for_standard_latency
  @use_slate_for_standard_latency
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



112
113
114
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 112

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 89

def self.attribute_map
  {
    :'playback_policy' => :'playback_policy',
    :'playback_policies' => :'playback_policies',
    :'advanced_playback_policies' => :'advanced_playback_policies',
    :'new_asset_settings' => :'new_asset_settings',
    :'reconnect_window' => :'reconnect_window',
    :'use_slate_for_standard_latency' => :'use_slate_for_standard_latency',
    :'reconnect_slate_url' => :'reconnect_slate_url',
    :'passthrough' => :'passthrough',
    :'audio_only' => :'audio_only',
    :'embedded_subtitles' => :'embedded_subtitles',
    :'generated_subtitles' => :'generated_subtitles',
    :'reduced_latency' => :'reduced_latency',
    :'low_latency' => :'low_latency',
    :'latency_mode' => :'latency_mode',
    :'test' => :'test',
    :'simulcast_targets' => :'simulcast_targets',
    :'max_continuous_duration' => :'max_continuous_duration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 359

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 140

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 117

def self.openapi_types
  {
    :'playback_policy' => :'Array<PlaybackPolicy>',
    :'playback_policies' => :'Array<PlaybackPolicy>',
    :'advanced_playback_policies' => :'Array<CreatePlaybackIDRequest>',
    :'new_asset_settings' => :'CreateAssetRequest',
    :'reconnect_window' => :'Float',
    :'use_slate_for_standard_latency' => :'Boolean',
    :'reconnect_slate_url' => :'String',
    :'passthrough' => :'String',
    :'audio_only' => :'Boolean',
    :'embedded_subtitles' => :'Array<LiveStreamEmbeddedSubtitleSettings>',
    :'generated_subtitles' => :'Array<LiveStreamGeneratedSubtitleSettings>',
    :'reduced_latency' => :'Boolean',
    :'low_latency' => :'Boolean',
    :'latency_mode' => :'String',
    :'test' => :'Boolean',
    :'simulcast_targets' => :'Array<CreateSimulcastTargetRequest>',
    :'max_continuous_duration' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      playback_policy == o.playback_policy &&
      playback_policies == o.playback_policies &&
      advanced_playback_policies == o.advanced_playback_policies &&
      new_asset_settings == o.new_asset_settings &&
      reconnect_window == o.reconnect_window &&
      use_slate_for_standard_latency == o.use_slate_for_standard_latency &&
      reconnect_slate_url == o.reconnect_slate_url &&
      passthrough == o.passthrough &&
      audio_only == o.audio_only &&
      embedded_subtitles == o.embedded_subtitles &&
      generated_subtitles == o.generated_subtitles &&
      reduced_latency == o.reduced_latency &&
      low_latency == o.low_latency &&
      latency_mode == o.latency_mode &&
      test == o.test &&
      simulcast_targets == o.simulcast_targets &&
      max_continuous_duration == o.max_continuous_duration
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 389

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = MuxRuby.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 460

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 366

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


346
347
348
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 346

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



352
353
354
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 352

def hash
  [playback_policy, playback_policies, advanced_playback_policies, new_asset_settings, reconnect_window, use_slate_for_standard_latency, reconnect_slate_url, passthrough, audio_only, embedded_subtitles, generated_subtitles, reduced_latency, low_latency, latency_mode, test, simulcast_targets, max_continuous_duration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 249

def list_invalid_properties
  invalid_properties = Array.new
  if !@reconnect_window.nil? && @reconnect_window > 1800
    invalid_properties.push('invalid value for "reconnect_window", must be smaller than or equal to 1800.')
  end

  if !@reconnect_window.nil? && @reconnect_window < 0
    invalid_properties.push('invalid value for "reconnect_window", must be greater than or equal to 0.')
  end

  if !@max_continuous_duration.nil? && @max_continuous_duration > 43200
    invalid_properties.push('invalid value for "max_continuous_duration", must be smaller than or equal to 43200.')
  end

  if !@max_continuous_duration.nil? && @max_continuous_duration < 60
    invalid_properties.push('invalid value for "max_continuous_duration", must be greater than or equal to 60.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 436

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 442

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



430
431
432
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 430

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



272
273
274
275
276
277
278
279
280
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 272

def valid?
  return false if !@reconnect_window.nil? && @reconnect_window > 1800
  return false if !@reconnect_window.nil? && @reconnect_window < 0
  latency_mode_validator = EnumAttributeValidator.new('String', ["low", "reduced", "standard"])
  return false unless latency_mode_validator.valid?(@latency_mode)
  return false if !@max_continuous_duration.nil? && @max_continuous_duration > 43200
  return false if !@max_continuous_duration.nil? && @max_continuous_duration < 60
  true
end