Class: MuxRuby::CreateSimulcastTargetRequest
- Inherits:
-
Object
- Object
- MuxRuby::CreateSimulcastTargetRequest
- Defined in:
- lib/mux_ruby/models/create_simulcast_target_request.rb
Instance Attribute Summary collapse
-
#passthrough ⇒ Object
Arbitrary metadata set by you when creating a simulcast target.
-
#stream_key ⇒ Object
Stream Key represents a stream identifier on the third party live streaming service to send the parent live stream to.
-
#url ⇒ Object
RTMP hostname including application name for the third party live streaming service.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSimulcastTargetRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSimulcastTargetRequest
Initializes the object
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 39 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'passthrough') self.passthrough = attributes[:'passthrough'] end if attributes.has_key?(:'stream_key') self.stream_key = attributes[:'stream_key'] end if attributes.has_key?(:'url') self.url = attributes[:'url'] end end |
Instance Attribute Details
#passthrough ⇒ Object
Arbitrary metadata set by you when creating a simulcast target.
11 12 13 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 11 def passthrough @passthrough end |
#stream_key ⇒ Object
Stream Key represents a stream identifier on the third party live streaming service to send the parent live stream to.
14 15 16 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 14 def stream_key @stream_key end |
#url ⇒ Object
RTMP hostname including application name for the third party live streaming service. Example: ‘rtmp://live.example.com/app’.
17 18 19 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 17 def url @url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 20 def self.attribute_map { :'passthrough' => :'passthrough', :'stream_key' => :'stream_key', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
101 102 103 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 101 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
29 30 31 32 33 34 35 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 29 def self.openapi_types { :'passthrough' => :'String', :'stream_key' => :'String', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
78 79 80 81 82 83 84 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 78 def ==(o) return true if self.equal?(o) self.class == o.class && passthrough == o.passthrough && stream_key == o.stream_key && url == o.url end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 129 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model MuxRuby.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 194 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 108 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
88 89 90 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 88 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
94 95 96 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 94 def hash [passthrough, stream_key, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
60 61 62 63 64 65 66 67 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 60 def list_invalid_properties invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
174 175 176 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 174 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 168 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
71 72 73 74 |
# File 'lib/mux_ruby/models/create_simulcast_target_request.rb', line 71 def valid? return false if @url.nil? true end |