Method: MuxRuby::UpdateAssetMasterAccessRequest#initialize
- Defined in:
- lib/mux_ruby/models/update_asset_master_access_request.rb
#initialize(attributes = {}) ⇒ UpdateAssetMasterAccessRequest
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/mux_ruby/models/update_asset_master_access_request.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MuxRuby::UpdateAssetMasterAccessRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MuxRuby::UpdateAssetMasterAccessRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'master_access') self.master_access = attributes[:'master_access'] end end |