Class: MuxRuby::CreateLiveStreamRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/mux_ruby/models/create_live_stream_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateLiveStreamRequest

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 54

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'playback_policy')
    if (value = attributes[:'playback_policy']).is_a?(Array)
      self.playback_policy = value
    end
  end

  if attributes.has_key?(:'new_asset_settings')
    self.new_asset_settings = attributes[:'new_asset_settings']
  end

  if attributes.has_key?(:'reconnect_window')
    self.reconnect_window = attributes[:'reconnect_window']
  end

  if attributes.has_key?(:'passthrough')
    self.passthrough = attributes[:'passthrough']
  end

  if attributes.has_key?(:'reduced_latency')
    self.reduced_latency = attributes[:'reduced_latency']
  end

  if attributes.has_key?(:'test')
    self.test = attributes[:'test']
  end

  if attributes.has_key?(:'simulcast_targets')
    if (value = attributes[:'simulcast_targets']).is_a?(Array)
      self.simulcast_targets = value
    end
  end
end

Instance Attribute Details

#new_asset_settingsObject

Returns the value of attribute new_asset_settings.



12
13
14
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 12

def new_asset_settings
  @new_asset_settings
end

#passthroughObject

Returns the value of attribute passthrough.



17
18
19
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 17

def passthrough
  @passthrough
end

#playback_policyObject

Returns the value of attribute playback_policy.



10
11
12
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 10

def playback_policy
  @playback_policy
end

#reconnect_windowObject

When live streaming software disconnects from Mux, either intentionally or due to a drop in the network, the Reconnect Window is the time in seconds that Mux should wait for the streaming software to reconnect before considering the live stream finished and completing the recorded asset. Defaults to 60 seconds on the API if not specified.



15
16
17
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 15

def reconnect_window
  @reconnect_window
end

#reduced_latencyObject

Latency is the time from when the streamer does something in real life to when you see it happen in the player. Set this if you want lower latency for your live stream. Note: Reconnect windows are incompatible with Reduced Latency and will always be set to zero (0) seconds. Read more here: mux.com/blog/reduced-latency-for-mux-live-streaming-now-available/



20
21
22
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 20

def reduced_latency
  @reduced_latency
end

#simulcast_targetsObject

Returns the value of attribute simulcast_targets.



24
25
26
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 24

def simulcast_targets
  @simulcast_targets
end

#testObject

Returns the value of attribute test.



22
23
24
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 22

def test
  @test
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
37
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 27

def self.attribute_map
  {
    :'playback_policy' => :'playback_policy',
    :'new_asset_settings' => :'new_asset_settings',
    :'reconnect_window' => :'reconnect_window',
    :'passthrough' => :'passthrough',
    :'reduced_latency' => :'reduced_latency',
    :'test' => :'test',
    :'simulcast_targets' => :'simulcast_targets'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



159
160
161
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 159

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 40

def self.openapi_types
  {
    :'playback_policy' => :'Array<PlaybackPolicy>',
    :'new_asset_settings' => :'CreateAssetRequest',
    :'reconnect_window' => :'Float',
    :'passthrough' => :'String',
    :'reduced_latency' => :'BOOLEAN',
    :'test' => :'BOOLEAN',
    :'simulcast_targets' => :'Array<CreateSimulcastTargetRequest>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



132
133
134
135
136
137
138
139
140
141
142
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 132

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      playback_policy == o.playback_policy &&
      new_asset_settings == o.new_asset_settings &&
      reconnect_window == o.reconnect_window &&
      passthrough == o.passthrough &&
      reduced_latency == o.reduced_latency &&
      test == o.test &&
      simulcast_targets == o.simulcast_targets
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 187

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    MuxRuby.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 252

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 166

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


146
147
148
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 146

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



152
153
154
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 152

def hash
  [playback_policy, new_asset_settings, reconnect_window, passthrough, reduced_latency, test, simulcast_targets].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 95

def list_invalid_properties
  invalid_properties = Array.new
  if !@reconnect_window.nil? && @reconnect_window > 300
    invalid_properties.push('invalid value for "reconnect_window", must be smaller than or equal to 300.')
  end

  if !@reconnect_window.nil? && @reconnect_window < 0.1
    invalid_properties.push('invalid value for "reconnect_window", must be greater than or equal to 0.1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



232
233
234
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 232

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



226
227
228
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 226

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



110
111
112
113
114
# File 'lib/mux_ruby/models/create_live_stream_request.rb', line 110

def valid?
  return false if !@reconnect_window.nil? && @reconnect_window > 300
  return false if !@reconnect_window.nil? && @reconnect_window < 0.1
  true
end